@@ -17,7 +17,6 @@ Shared utilities.
 
 from ._data import MOPool
 from ._data import pools
-from ._data import unique
 
 
 def get_objects(namespace, pool_name_key, managed_objects, search_function,
@@ -39,11 +38,12 @@ def get_objects(namespace, pool_name_key, managed_objects, search_function,
     :returns: objects of interest and a map from pool object path to name
     :rtype: list * dict
     """
-    if getattr(namespace, pool_name_key, None) is not None:
-        (parent_pool_object_path, _) = unique(
+    pool_name = getattr(namespace, pool_name_key, None)
+    if pool_name is not None:
+        (parent_pool_object_path, _) = next(
             pools(props={
-                'Name': namespace.pool_name
-            }).search(managed_objects))
+                'Name': pool_name
+            }).require_unique_match(True).search(managed_objects))
 
         properties = {"Pool": parent_pool_object_path}
         path_to_name = {parent_pool_object_path: namespace.pool_name}
